==> linm-0.7.5b.tar.gz: linm-0.7.5b/src/ncurses/cmd_mcd_imp.h <==
#ifndef __MLS_CMD_MCD_IMP_H__
#define __MLS_CMD_MCD_IMP_H__

#include "define.h"
#include "mlslocale.h"
#include "mlscfgload.h"
#include "ncurses_panel.h"
#include "ncurses_mcd.h"
#include "ncurses_editor.h"
#include "command.h"
#include "selection.h"

// PluginLoader 때문.
#include "vfsplugin.h"
#include "readerctl.h"

namespace MLS {

class CmdMcdImp:public Configurable
{
private:
	NCurses_Panel*			_pPanel;
	NCurses_Mcd*			_pMcd;
	NCurses_Editor*			_pEditor;
	vector<NCurses_Panel*>	_pCurPanel;

public:
	CmdMcdImp() : _pPanel(NULL), _pMcd(NULL)
	{
		UpdateConfig();

		// 이것은 Copy&Paste를 위해서 따로 쓰이는 Reader이다.
		// 여기에서 한번만 로드
		PluginLoader(&g_tReaderCtl);
	}

	~CmdMcdImp() 					{ SaveConfig(); }

	void SetPanel(NCurses_Panel* p)		{ _pPanel = p; }
	void SetMcd(NCurses_Mcd* p)			{ _pMcd = p; }
	void SetEditor(NCurses_Editor* p)	{ _pEditor = p; }

	NCurses_Mcd* 	GetMcd()		{ return _pMcd; }	
	NCurses_Panel* 	GetPanel()		{ return _pPanel; }
	NCurses_Editor* GetEditor()		{ return _pEditor; }

	// IConfigurable
	void UpdateConfig();
	void SaveConfig();

	void	GoRoot();
	void	GoHome();
	void	GoParent();

	void	Key_Enter();
	void	Key_Left();
	void	Key_Right();
	void	Key_Up();
	void	Key_Down();
	void	Key_Home();
	void	Key_End();
	void	Key_Ins()	{ PasteClip(); }
	void	Key_Del()	{ Remove(); }
	void	Key_BS()	{ Key_Left();  }
	void	Key_PageUp();
	void	Key_PageDown();
	void	Key_ESC();
	
	void	Refresh();

	void	RemoteConnect();
	void	RemoteClose();

	void	Menu();
	
	void	Quit();	
	void	Split();
	void	NextWindow();
	void	SplitViewSync();
	void	ViewSync();

	void	Remove();
	void	CopyClip();
	void	PasteClip();
	void	CutClip();

	void	Rename();
	void	Mkdir();

	void	Shell();

	void	McdSubDirOneSearch()	{	_pMcd->SubDirOneSearch();	}
	void	McdSubDirAllSearch()	{	_pMcd->SubDirAllSearch();	}
	void	McdSubDirClear() 		{	_pMcd->SubDirClear(); }

	void 	BoxCodeChange();
	void 	LangChange()
	{
		if (e_nCurLang == US)
			Set_Locale(AUTO);
		else
			Set_Locale(US);
	}

	void	HiddenFileView();

	void	AllScan();
	void	Scan();

	void	MountList();
	void	SizeInfo();

protected:
	void	CutPaste();
	void	CopyPaste();
}; // class CommandImp

}; // namespace

#endif

==> linm_0.7.6-1.tar.gz: linm-0.7.6/src/ncurses/cmd_mcd_imp.h <==
#ifndef __MLS_CMD_MCD_IMP_H__
#define __MLS_CMD_MCD_IMP_H__

#include "cmd_common_imp.h"

#include "command.h"
#include "selection.h"

// PluginLoader 때문.
#include "vfsplugin.h"
#include "readerctl.h"

namespace MLS {

class CmdMcdImp:public CmdCommonImp, public Configurable
{
private:
	vector<NCurses_Panel*>	_pCurPanel;

public:
	CmdMcdImp() : CmdCommonImp()
	{
		UpdateConfig();

		// 이것은 Copy&Paste를 위해서 따로 쓰이는 Reader이다.
		// 여기에서 한번만 로드
		PluginLoader(&g_tReaderCtl);
	}

	~CmdMcdImp() 					{ SaveConfig(); }

	// IConfigurable
	void UpdateConfig();
	void SaveConfig();

	void	GoRoot();
	void	GoHome();
	void	GoParent();

	void	Key_Enter();
	void	Key_Left();
	void	Key_Right();
	void	Key_Up();
	void	Key_Down();
	void	Key_Home();
	void	Key_End();
	void	Key_Ins()	{ PasteClip(); }
	void	Key_Del()	{ Remove(); }
	void	Key_BS()	{ Key_Left();  }
	void	Key_PageUp();
	void	Key_PageDown();
	void	Key_ESC();
	
	void	Refresh();

	void	RemoteConnect();
	void	RemoteClose();

	void	Menu();
	
	void	Quit();	
	void	Split();
	void	NextWindow();
	void	SplitViewSync();
	void	ViewSync();

	void	Remove();
	void	CopyClip();
	void	PasteClip();
	void	CutClip();

	void	Rename();
	void	Mkdir();

	void	Shell();

	void	McdSubDirOneSearch()	{	_pMcd->SubDirOneSearch();	}
	void	McdSubDirAllSearch()	{	_pMcd->SubDirAllSearch();	}
	void	McdSubDirClear() 		{	_pMcd->SubDirClear(); }

	void	HiddenFileView();

	void	AllScan();
	void	Scan();

	void	MountList();
	void	SizeInfo();

	void 	McdLoad();
	void 	McdSave();

protected:
	void	CutPaste();
	void	CopyPaste();
}; // class CommandImp

}; // namespace

#endif
